@@ -40,14 +40,15 @@
 #include <KConfigDialog>
 #include <KGameClock>
 #include <KGamePopupItem>
-#include <KGlobal>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KScoreDialog>
-#include <KStandardDirs>
+
 #include <KStandardGameAction>
-#include <KStatusBar>
+#include <QStatusBar>
 #include <KToggleAction>
+#include <QIcon>
+#include <QStandardPaths>
 
 
 #include "kbbgamedoc.h"
@@ -75,10 +76,10 @@ KBBMainWindow::KBBMainWindow()
 
 
 	// Status bar
-	statusBar()->insertPermanentItem("", SRUN, 1);
-	statusBar()->insertPermanentItem(i18n("Time: 00:00"), STIME, 1);
-	statusBar()->insertPermanentItem(i18n("Size: 00 x 00"), SSIZE);
-	statusBar()->setItemAlignment(SRUN, Qt::AlignLeft | Qt::AlignVCenter);
+    //QT5 statusBar()->insertPermanentItem("", SRUN, 1);
+    //QT5 statusBar()->insertPermanentItem(i18n("Time: 00:00"), STIME, 1);
+    //QT5 statusBar()->insertPermanentItem(i18n("Size: 00 x 00"), SSIZE);
+    //QT5 statusBar()->setItemAlignment(SRUN, Qt::AlignLeft | Qt::AlignVCenter);
 
 
 	// Difficulty
@@ -98,24 +99,24 @@ KBBMainWindow::KBBMainWindow()
 	m_pauseAction = KStandardGameAction::pause(this, SLOT(pause(bool)), actionCollection());
 	QAction* tutorial = actionCollection()->addAction( QLatin1String( "game_tutorial" ));
 	tutorial->setText(i18n("Start Tutorial"));
-	tutorial->setIcon(KIcon( QLatin1String( "footprint" )));
+	tutorial->setIcon(QIcon::fromTheme( QLatin1String( "footprint" )));
 	tutorial->setToolTip(i18n("Start tutorial"));
 	tutorial->setWhatsThis(i18n("<qt>The <b>tutorial</b> is a fast, user friendly and interactive way to learn the rules of the game. Start it if you do not know them!</qt>"));
-	connect(tutorial, SIGNAL(triggered(bool)), SLOT(startTutorial()));
+	connect(tutorial, &QAction::triggered, this, &KBBMainWindow::startTutorial);
 	KStandardGameAction::quit(this, SLOT(close()), actionCollection());
 	QAction* sandbox = actionCollection()->addAction( QLatin1String( "game_sandbox" ));
 	sandbox->setText(i18n("New Sandbox Game"));
 	sandbox->setToolTip(i18n("Start a new sandbox game"));
 	sandbox->setWhatsThis(i18n("<qt><p>In a <b>sandbox game</b>, the solution is displayed at the beginning of the game. This is useful to understand the game principles.</p><p>However: after a while, it is not really fun and you should try to start a real game!</p></qt>"));
-	connect(sandbox, SIGNAL(triggered(bool)), SLOT(startSandbox()));
+	connect(sandbox, &QAction::triggered, this, &KBBMainWindow::startSandbox);
 	KStandardGameAction::highscores(this, SLOT(showHighscores()), actionCollection());
 
 	// Menu "Move"
 	m_doneAction = actionCollection()->addAction( QLatin1String( "move_done" ));
 	m_doneAction->setText(i18nc("This is the last action of a game to check the result, when the user is done.", "Done!"));
 	m_doneAction->setWhatsThis(i18n("<qt><ul><li>First, you have to place all the balls on the black box. To guess the correct positions of the balls and see how they interact with laser beams, you should use the lasers that are positioned around the black box.</li><li><b>When you think you are done</b>, you should click here.</li></ul><p>Note that it is only possible to click here if you have placed the correct number of balls.</p></qt>"));
-	m_doneAction->setIcon(KIcon( QLatin1String( "dialog-ok" )));
-	connect(m_doneAction, SIGNAL(triggered(bool)), SLOT(done()));
+	m_doneAction->setIcon(QIcon::fromTheme( QLatin1String( "dialog-ok" )));
+	connect(m_doneAction, &QAction::triggered, this, &KBBMainWindow::done);
 	m_solveAction = KStandardGameAction::solve(this, SLOT(solve()), actionCollection());
 	m_solveAction->setToolTip(i18n("Give up the game"));
 	m_solveAction->setWhatsThis(i18n("<qt><p>Choose \"<b>Solve</b>\" if you want to give up the current game. The solution will be displayed.</p><p>If you placed all the balls and do not want to give up, choose \"Done!\".</p></qt>"));
@@ -127,7 +128,7 @@ KBBMainWindow::KBBMainWindow()
 	// Theme manager
 	QString svgzFile = KBBPrefs::theme();
 	if (!QFile(svgzFile).exists())
-		svgzFile = KStandardDirs::locate("appdata", "pics/kblackbox.svgz");
+        svgzFile = QStandardPaths::locate(QStandardPaths::DataLocation, QLatin1Literal("pics/kblackbox.svgz"));
 	m_themeManager = new KBBThemeManager(svgzFile);
 	
 	
@@ -137,8 +138,8 @@ KBBMainWindow::KBBMainWindow()
 
 	// Board
 	m_gameDoc = new KBBGameDoc(this, m_tutorial);
-	connect(m_gameDoc, SIGNAL(updateStats()), this, SLOT(updateStats()) );
-	connect(m_gameDoc, SIGNAL(isRunning(bool)), SLOT(setRunning(bool)));
+	connect(m_gameDoc, &KBBGameDoc::updateStats, this, &KBBMainWindow::updateStats);
+	connect(m_gameDoc, &KBBGameDoc::isRunning, this, &KBBMainWindow::setRunning);
 
 
 	// Game widget
@@ -157,46 +158,46 @@ KBBMainWindow::KBBMainWindow()
 
 
 	// Keyboard only
-	KAction* action = actionCollection()->addAction( QLatin1String(  "move_down" ) );
+	QAction * action = actionCollection()->addAction( QLatin1String(  "move_down" ) );
 	action->setText( i18n("Move Down") );
-	connect(action, SIGNAL(triggered(bool)), m_gameWidget, SLOT(keyboardMoveDown()));
-	action->setShortcut(Qt::Key_Down);
+	connect(action, &QAction::triggered, m_gameWidget, &KBBScalableGraphicWidget::keyboardMoveDown);
+    actionCollection()->setDefaultShortcut(action, Qt::Key_Down);
 	addAction(action);
 	
 	action = actionCollection()->addAction( QLatin1String(  "move_up" ) );
 	action->setText( i18n("Move Up") );
-	connect(action, SIGNAL(triggered(bool)), m_gameWidget, SLOT(keyboardMoveUp()));
-	action->setShortcut(Qt::Key_Up);
+	connect(action, &QAction::triggered, m_gameWidget, &KBBScalableGraphicWidget::keyboardMoveUp);
+    actionCollection()->setDefaultShortcut(action,Qt::Key_Up);
 	addAction(action);
 	
 	action = actionCollection()->addAction( QLatin1String(  "move_left" ) );
 	action->setText( i18n("Move Left") );
-	connect(action, SIGNAL(triggered(bool)), m_gameWidget, SLOT(keyboardMoveLeft()));
-	action->setShortcut(Qt::Key_Left);
+	connect(action, &QAction::triggered, m_gameWidget, &KBBScalableGraphicWidget::keyboardMoveLeft);
+    actionCollection()->setDefaultShortcut(action, Qt::Key_Left);
 	addAction(action);
 	
 	action = actionCollection()->addAction( QLatin1String(  "move_right" ) );
 	action->setText( i18n("Move Right") );
-	connect(action, SIGNAL(triggered(bool)), m_gameWidget, SLOT(keyboardMoveRight()));
-	action->setShortcut(Qt::Key_Right);
+	connect(action, &QAction::triggered, m_gameWidget, &KBBScalableGraphicWidget::keyboardMoveRight);
+    actionCollection()->setDefaultShortcut(action, Qt::Key_Right);
 	addAction(action);
 	
 	action = actionCollection()->addAction( QLatin1String( "switch_ball" ));
 	action->setText(i18n("Switch Ball or Shoot Laser"));
-	connect(action, SIGNAL(triggered(bool)), m_gameWidget, SLOT(keyboardEnter()));
-	action->setShortcut(Qt::Key_Return);
+	connect(action, &QAction::triggered, m_gameWidget, &KBBScalableGraphicWidget::keyboardEnter);
+    actionCollection()->setDefaultShortcut(action, Qt::Key_Return);
 	addAction(action);
 	
 	action = actionCollection()->addAction( QLatin1String( "switch_marker" ));
 	action->setText(i18n("Switch Marker"));
-	connect(action, SIGNAL(triggered(bool)), m_gameWidget, SLOT(keyboardSpace()));
-	action->setShortcut(Qt::Key_Space);
+	connect(action, &QAction::triggered, m_gameWidget, &KBBScalableGraphicWidget::keyboardSpace);
+    actionCollection()->setDefaultShortcut(action, Qt::Key_Space);
 	addAction(action);
 
 
 	m_gameClock = new KGameClock(this, KGameClock::MinSecOnly);
-	connect(m_gameClock, SIGNAL(timeChanged(QString)), SLOT(updateStats()));
-	connect(m_gameClock, SIGNAL(timeChanged(QString)), m_gameDoc, SLOT(timeChanged()));
+	connect(m_gameClock, &KGameClock::timeChanged, this, &KBBMainWindow::updateStats);
+	connect(m_gameClock, &KGameClock::timeChanged, m_gameDoc, &KBBGameDoc::timeChanged);
 
 
 	levelChanged();
@@ -210,7 +211,7 @@ KBBMainWindow::KBBMainWindow()
 
 KBBMainWindow::~KBBMainWindow()
 {
-	KBBPrefs::self()->writeConfig();
+	KBBPrefs::self()->save();
 
 	delete m_gameWidget;
 	delete m_themeManager;
@@ -306,24 +307,26 @@ void KBBMainWindow::updateStats()
 
 
 	// Status bar
-	if (m_tutorial->isVisible())
-		statusBar()->changeItem(i18n("Tutorial"), SRUN );
+    if (m_tutorial->isVisible()) {
+        //QT5 statusBar()->changeItem(i18n("Tutorial"), SRUN );
+    }
 	if (!m_tutorial->isVisible()) {
 		if (m_boardEnabled) {
 			if (ballsLeftToPlace<0) {
-				statusBar()->changeItem((i18np("1 ball too many!", "%1 balls too many!", -ballsLeftToPlace)), SRUN);
+                //QT5 statusBar()->changeItem((i18np("1 ball too many!", "%1 balls too many!", -ballsLeftToPlace)), SRUN);
 			} else if (ballsLeftToPlace==0) {
-				statusBar()->changeItem(i18n("No more balls to place"), SRUN);
+                //QT5 statusBar()->changeItem(i18n("No more balls to place"), SRUN);
 			} else if (ballsLeftToPlace>0) {
-				statusBar()->changeItem(i18np("1 ball to place", "%1 balls to place", ballsLeftToPlace), SRUN);
+                //QT5 statusBar()->changeItem(i18np("1 ball to place", "%1 balls to place", ballsLeftToPlace), SRUN);
 			}	
-		} else
-			statusBar()->changeItem(i18n("Game over"), SRUN );
+        } else {
+            //QT5 statusBar()->changeItem(i18n("Game over"), SRUN );
+        }
 	}
 
-	statusBar()->changeItem(i18n("Time: %1", m_gameClock->timeString()), STIME);
+    //QT5 statusBar()->changeItem(i18n("Time: %1", m_gameClock->timeString()), STIME);
 
-	statusBar()->changeItem( i18n("Size: %1 x %2", m_gameDoc->columns(), m_gameDoc->rows()), SSIZE );
+    //QT5 statusBar()->changeItem( i18n("Size: %1 x %2", m_gameDoc->columns(), m_gameDoc->rows()), SSIZE );
 	
 	
 	// 2. Info Widget
@@ -348,7 +351,7 @@ void KBBMainWindow::done()
 		if (score <= (m_ballNumber*35)) {
 			s = i18nc("The text may not be too wide. So please use some HTML-BR-tags to have something more or less as wide as in english. Thanks!", "Your final score is: %1.<br />You did really well!", score);
 			if (m_sandboxMode)
-				s += QString("<br /><br />") + i18nc("The text may not be too wide. So please use some HTML-BR-tags to have something more or less as wide as in english. Thanks!", "But it does not count<br />because <b>it is the sandbox!</b>");
+                s += QString::fromLatin1("<br /><br />") + i18nc("The text may not be too wide. So please use some HTML-BR-tags to have something more or less as wide as in english. Thanks!", "But it does not count<br />because <b>it is the sandbox!</b>");
 		} else
 			s = i18nc("The text may not be too wide. So please use some HTML-BR-tags to have something more or less as wide as in english. Thanks!", "Your final score is: %1.<br />I guess you need more practice.", score);
 
@@ -381,7 +384,7 @@ void KBBMainWindow::pause(bool state)
 		m_gameWidget->popupText(i18n("Game paused.<br />Press \"%1\" to resume.", m_pauseAction->shortcut().toString(QKeySequence::NativeText)), 0);
 	} else {
 		m_gameClock->resume();
-		m_gameWidget->popupText("");
+        m_gameWidget->popupText(QString());
 	}
 	m_solveAction->setEnabled(!state);
 
@@ -410,12 +413,12 @@ void KBBMainWindow::settingsChanged()
 
 void KBBMainWindow::settingsDialog()
 {
-	if (!KConfigDialog::showDialog("settings")) {
-		KConfigDialog *dialog = new KConfigDialog(this, "settings", KBBPrefs::self());
+    if (!KConfigDialog::showDialog(QLatin1Literal("settings"))) {
+        KConfigDialog *dialog = new KConfigDialog(this, QLatin1Literal("settings"), KBBPrefs::self());
 		m_levelConfig = new KBBLevelConfigurationWidget(dialog, m_customBallNumber, m_customColumns, m_customRows, m_themeManager);
-		dialog->addPage(m_levelConfig, i18n("Custom Game"), "games-config-custom");
-		connect(dialog, SIGNAL(settingsChanged(QString)), this, SLOT(settingsChanged()));
-                dialog->setHelp(QString(), "kblackbox");
+        dialog->addPage(m_levelConfig, i18n("Custom Game"), QLatin1Literal("games-config-custom"));
+		connect(dialog, &KConfigDialog::settingsChanged, this, &KBBMainWindow::settingsChanged);
+                //QT5 dialog->setHelp(QString(), "kblackbox");
 		dialog->show();
 	}
 }
@@ -435,7 +438,7 @@ void KBBMainWindow::solve()
 		KMessageBox::sorry(this, i18n("Sorry, you may not give up during the tutorial."), i18n("Solve"));
 	} else {
 		if (m_gameDoc->numberOfBallsToPlace()==m_gameDoc->numberOfBallsPlaced()) {
-			if (KMessageBox::warningContinueCancel(this, i18n("You placed all the balls. Great!\nYou should now click on \"Done!\" to end the game and check if you guessed correctly.\nSo, do you really want to give up this game?"), QString(), KGuiItem(i18n("Give up"))) == KMessageBox::Continue)
+			if (KMessageBox::warningContinueCancel(this, i18n("You placed all the balls. Great!\nYou should now click on \"Done!\" to end the game and check if you guessed correctly.\nSo, do you really want to give up this game?"), QString(), KGuiItem(i18n("Give up"))) == KMessageBox::Continue)
 				solving();
 		} else if (KMessageBox::warningContinueCancel(this, i18np("You should place %1 ball!\n", "You should place %1 balls!\n", m_gameDoc->numberOfBallsToPlace()) + i18np("You have placed %1.\n", "You have placed %1.\n", m_gameDoc->numberOfBallsPlaced()) + i18n("Do you really want to give up this game?"), QString(), KGuiItem(i18n("Give up"))) == KMessageBox::Continue)
 			solving();
@@ -525,4 +528,4 @@ void KBBMainWindow::startGame(bool sandboxMode)
 
 
 
-#include "kbbmainwindow.moc"
+
